import { PageComponent, StyleSheet, View } from '@seatalk-rn/sdk-components'
import { ILogger } from '@seatalk-rn/sdk-logger'
import { CalendarPicker, NavBarPage, SolidButton } from '@seatalk-rn/sdk-widgets'
import React from 'react'
import { ScrollView } from 'react-native'
import { sdkClient } from '../client'

export class CalendarTestPage extends PageComponent {
    private logger: Promise<ILogger>

    constructor(props: {}) {
        super(props)
        this.logger = sdkClient.then(client => client.buildLogger('CalendarTestPage'))
    }

    getPageName(): string {
        return 'CalendarTestPage'
    }

    async onPressCalendarSingleDate() {
        const result = await CalendarPicker.selectDates({ type: 'SingleDate' })
        if (result.wasCancelled) {
            console.log('Here');
            (await this.logger).verbose('cancelled', undefined)
        } else {
            console.log('Here 1');
            (await this.logger).verbose(`${result.selectedDates}`, 'CalendarPage')
        }
    }

    async onPressCalendarDateRange() {
        const result = await CalendarPicker.selectDates({ type: 'DateRange' })
        if (result.wasCancelled) {
            (await this.logger).verbose('cancelled', undefined)
        } else {
            (await this.logger).verbose(`${result.selectedDates}`, 'CalendarPage')
        }
    }

    async onPressCalendarDateRangeWithHalfDay() {
        const result = await CalendarPicker.selectDates({ type: 'DateRangeWithHalfDay' })
        if (result.wasCancelled) {
            (await this.logger).verbose('cancelled', undefined)
        } else {
            (await this.logger).verbose(`${result.selectedDates}`, 'CalendarPage')
        }
    }

    async onPressCalendarInitialSelection() {
        const result = await CalendarPicker.selectDates({
            type: 'DateRangeWithHalfDay',
            initialSelection: [
                { date: '06-08-2020', period: 'AM' },
                { date: '06-08-2020', period: 'PM' }
            ]
        })
        if (result.wasCancelled) {
            (await this.logger).verbose('cancelled', undefined)
        } else {
            (await this.logger).verbose(`${result.selectedDates}`, 'CalendarPage')
        }
    }

    render() {
        return (
            <NavBarPage title="FileSystem Test" backButtonType="back">
                <ScrollView>
                    <View style={styles.container}>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Calendar-Single Date"
                                onPress={() => this.onPressCalendarSingleDate()}
                            />
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Calendar-Date Range"
                                onPress={() => this.onPressCalendarDateRange()}
                            />
                        </View>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Calendar-Date Range With Half Day"
                                onPress={() => this.onPressCalendarDateRangeWithHalfDay()}
                            />
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Calendar-Initial Selection"
                                onPress={() => this.onPressCalendarInitialSelection()}
                            />
                        </View>
                    </View>
                </ScrollView>
            </NavBarPage>
        )
    }
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center'
    },
    button: {
        height: 80,
        display: 'flex',
        flexDirection: 'row'
    },
    solidButton: {
        marginHorizontal: 20,
        width: 160,
        height: 44
    }
})
