import { PageComponent, StyleSheet, View } from '@seatalk-rn/sdk-components'
import { Alert, BorderButton, HUD, NavBarPage, SolidButton } from '@seatalk-rn/sdk-widgets'
import React from 'react'
import { ScrollView } from 'react-native'

export class ComponentsTestPage extends PageComponent {
    getPageName(): string {
        return 'ComponentsTestPage'
    }

    onPressHUD() {
        HUD.hudShowLoading()
        setTimeout(() => HUD.hudShowSuccess('Success'), 500)
    }

    onPressErrorHUD() {
        HUD.hudShowLoading()
        setTimeout(() => HUD.hudShowError('Error'), 500)
    }

    async onPressAlert() {
        await Alert.show(
            'This is an alert title',
            'This is an alert subtitle',
            {
                title: 'Confirm',
                style: 'normal',
                callback: () => HUD.hudShowSuccess('Confirmed'),
            },
            {
                title: 'Cancel',
                style: 'critical',
                callback: () => HUD.hudShowSuccess('Cancelled'),
            }
        )
    }

    async onPressAlertInput() {
        await Alert.show(
            'This is an alert title',
            'This is an alert subtitle',
            {
                title: 'Confirm',
                style: 'normal',
                callback: input => HUD.hudShowSuccess(`Confirmed: ${input}`),
            },
            {
                title: 'Cancel',
                style: 'critical',
                callback: () => HUD.hudShowSuccess('Cancelled'),
            },
            {
                placeholder: 'Customizable placeholder',
                prefilledText: 'Prefilled Text',
                maxInputLength: 20,
            }
        )
    }

    render() {
        return (
            <NavBarPage title="FileSystem Test" backButtonType="back">
                <ScrollView>
                    <View style={styles.container}>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="SolidButton"
                                onPress={() => this.onPressHUD()}
                            />
                            <SolidButton
                                critical={true}
                                backgroundStyle={styles.solidButton}
                                enabled={false}
                                title="SolidButton"
                                onPress={() => this.onPressHUD()}
                            />
                        </View>
                        <View style={styles.button}>
                            <BorderButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="BorderButton"
                                onPress={() => this.onPressHUD()}
                            />
                            <BorderButton
                                critical={true}
                                backgroundStyle={styles.solidButton}
                                enabled={false}
                                title="BorderButton"
                                onPress={() => this.onPressHUD()}
                            />
                        </View>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Success HUD"
                                onPress={() => this.onPressHUD()}
                            />
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Error HUD"
                                onPress={() => this.onPressErrorHUD()}
                            />
                        </View>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Alert"
                                onPress={() => this.onPressAlert()}
                            />
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Alert (Input)"
                                onPress={() => this.onPressAlertInput()}
                            />
                        </View>
                    </View>
                </ScrollView>
            </NavBarPage>
        )
    }
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },
    button: {
        height: 80,
        display: 'flex',
        flexDirection: 'row',
    },
    solidButton: {
        marginHorizontal: 20,
        width: 160,
        height: 44,
    },
})
