import { Image, PageComponent } from '@seatalk-rn/sdk-components'
import { ImageInfo } from '@seatalk-rn/sdk-widgets'
import React, { ReactNode } from 'react'
import { Dimensions, FlatList } from 'react-native'

interface Props {
    images: ImageInfo[]
}

export class ImageViewerPage extends PageComponent<Props> {
    getPageName(): string {
        return 'ImageViewerPage'
    }

    render(): ReactNode {
        const { width, height } = Dimensions.get('window')
        return (
            <FlatList
                data={this.props.images.map(image => ({ key: image.fileUri, image }))}
                renderItem={({ item: { key, image } }) => {
                    const scale = Math.min(width / image.width, height / image.height)
                    return (
                        <Image
                            key={key}
                            source={{
                                uri: image.fileUri,
                                width: image.width * scale,
                                height: image.height * scale,
                            }}
                        />
                    )
                }}
            />
        )
    }
}
