import { PageComponent, StyleSheet, View } from '@seatalk-rn/sdk-components'
import { NavBarPage, SolidButton } from '@seatalk-rn/sdk-widgets'
import React, { ReactNode } from 'react'
import { ScrollView } from 'react-native'
import { sdkClient } from '../../client'

export class WebViewTestPage extends PageComponent {
    getPageName(): string {
        return 'WebViewTestPage'
    }

    render(): ReactNode {
        return (
            <NavBarPage title="WebView Test" backButtonType={'back'}>
                <ScrollView>
                    <View style={styles.container}>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Normal WebView"
                                onPress={() => WebViewTestPage.onPressNormalWebView()}
                            />
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Fullscreen Video"
                                onPress={() => WebViewTestPage.onPressFullscreenVideo()}
                            />
                        </View>
                        <View style={styles.button}>
                            <SolidButton
                                backgroundStyle={styles.solidButton}
                                enabled={true}
                                title="Redirect URL"
                                onPress={() => WebViewTestPage.onPressRedirectURL()}
                            />
                        </View>
                    </View>
                </ScrollView>
            </NavBarPage>
        )
    }

    private static async onPressNormalWebView() {
        await (await sdkClient).navigator.push('/webview_normal')
    }

    private static async onPressFullscreenVideo() {
        await (await sdkClient).navigator.push('/fullscreen_video')
    }

    private static async onPressRedirectURL() {
        await (await sdkClient).navigator.push('/webview_redirect_url')
    }
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },
    button: {
        height: 80,
        display: 'flex',
        flexDirection: 'row',
    },
    solidButton: {
        marginHorizontal: 20,
        width: 160,
        height: 44,
    },
})
