function createHTML({
    videoUrl = '',
    thumbnailUrl = '',
    cssText = '',
}: { videoUrl?: string; thumbnailUrl?: string; cssText?: string } = {}): string {
    return `
<!DOCTYPE html>
<html>
<head>
    <meta name="viewport" content="user-scalable=1.0,initial-scale=1.0,minimum-scale=1.0,maximum-scale=1.0">
    <style>
        * {outline: 0px solid transparent;-webkit-tap-highlight-color: rgba(0,0,0,0);-webkit-touch-callout: none;}
        html, body { margin: 0; padding: 0;font-family: Arial, Helvetica, sans-serif; font-size:1em; overflow: hidden;}
        body { -webkit-overflow-scrolling: touch;height: 100%; }
        video {margin-left:auto;margin-right:auto;display: block;}
        .content { position: relative; z-index: 1; }
        .content div { line-height:1.2;  }
        .content_box { position: relative; z-index: 2; background-color: #000; }
        #resize_inspector { position: absolute; z-index: 1; top: 0; left: 0; width: 100%; height: 100%; visibility:hidden; }
        div{ overflow: hidden;line-height:1.5; color: #202325 }
        video{ max-width: 100%; max-height: 400px; }
        ${cssText}
    </style>
</head>
<body>
<div class="content">
  <div class="content_box">
    <video controls playsinline poster="${thumbnailUrl}" controlsList="nodownload">
      <source src="${videoUrl}" type="video/mp4">
    <video/>
  </div>
  <iframe src="" frameborder="0" id="resize_inspector"></iframe>
</div>
<script>
    (function(exports) {
      var body = document.body, docEle = document.documentElement;
      var o_height = 0;
      var $resizeInspector = document.getElementById('resize_inspector');
      var addEventListener = function addEventListener(parent, type, listener) {
        return parent.addEventListener(type, listener);
      };

      var postAction = function(data) {
        exports.window.postMessage(JSON.stringify(data));
      };
      console.log = function() {
        postAction({type: 'Log', data: Array.prototype.slice.call(arguments)});
      };

      var Actions = {
        UPDATE_HEIGHT: function() {
          // 确保内容在body内滚动
          var height = body.scrollHeight;
          if (o_height !== height) {
            postAction({type: 'OffsetHeight', data: o_height = height});
          }
        },
      };
      var init = function init() {
        var message = function(event) {
          var msgData = JSON.parse(event.data), action = Actions[msgData.type];
          if (action) {
            if (msgData.name && action[msgData.name]) {
              action[msgData.name](msgData.data);
            }
          }
        };

        document.addEventListener('message', message, false);
        window.addEventListener('message', message, false);

        $resizeInspector.contentWindow.addEventListener('resize', function() {
          Actions.UPDATE_HEIGHT();
        });

        Actions.UPDATE_HEIGHT();
      };
      init();
    })({
      window: window.ReactNativeWebView || window.parent,
    });
</script>
</body>
</html>
`
}

const HTML = createHTML()
export { HTML, createHTML }
